@@ -47,11 +47,15 @@ class Command(object):
     CLICK_ELEMENT = "clickElement"
     HOVER_OVER_ELEMENT = "hoverOverElement"
     SEND_KEYS_TO_ELEMENT = "sendKeysToElement"
-    SEND_MODIFIER_KEY_TO_ACTIVE_ELEMENT = "sendModifierKeyToActiveElement"
+    SEND_KEYS_TO_ACTIVE_ELEMENT = "sendKeysToActiveElement"
     SUBMIT_ELEMENT = "submitElement"
     TOGGLE_ELEMENT = "toggleElement"
     GET_CURRENT_WINDOW_HANDLE = "getCurrentWindowHandle"
     GET_WINDOW_HANDLES = "getWindowHandles"
+    GET_WINDOW_SIZE = "getWindowSize"
+    GET_WINDOW_POSITION = "getWindowPosition"
+    SET_WINDOW_SIZE = "setWindowSize"
+    SET_WINDOW_POSITION = "setWindowPosition"
     SWITCH_TO_WINDOW = "switchToWindow"
     SWITCH_TO_FRAME = "switchToFrame"
     GET_ACTIVE_ELEMENT = "getActiveElement"
